@@ -1,8 +1,8 @@
 ## File Name: reglca_freq_ll.R
-## File Version: 0.06
+## File Version: 0.08
 
 reglca_freq_ll <- function(x,C,W)
 {
     eps <- 1E-20
-    sum( C * log(x+eps) + W * log( 1 - x + eps) )
+    sum( C * cdm_log(x, eps) + W * cdm_log( 1 - x, eps) )
 }
